| Title: | A Fast 'WHATWG' Compliant URL Parser in Rust |
|---|---|
| Description: | A 'WHATWG' compliant and fast URL parser written in Rust using the crate url. |
| Authors: | David Schoch [aut, cre] (ORCID: <https://orcid.org/0000-0003-2952-4812>) |
| Maintainer: | David Schoch <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-05-24 05:56:26 UTC |
| Source: | https://github.com/schochastics/urlparser |
Use url crate to parse a url
rs_url_parse(url)rs_url_parse(url)
url |
character. one or more URL to be parsed |
A data frame of the url components: href, protocol, username, password, host, hostname, port, pathname, search, and hash
rs_url_parse("https://user_1:[email protected]:8080/dir/../api?q=1#frag")rs_url_parse("https://user_1:[email protected]:8080/dir/../api?q=1#frag")